<?php
/*
Plugin Name: Product Sections for WooCommerce (EasyToolsWP)
Description: Create custom tabs or sections for WooCommerce products with multiple display positions.
Version: 1.8.1
Author: EasyToolsWP.com
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

// Register custom post type
function etwp_register_custom_sections() {
    $labels = array(
        'name' => 'Product Sections',
        'singular_name' => 'Product Section',
        'menu_name' => 'Product Sections',
        'name_admin_bar' => 'Product Section',
    );
    
    $args = array(
        'labels' => $labels,
        'public' => true,
        'show_ui' => true,
        'show_in_menu' => true,
        'supports' => array( 'title', 'editor' ), // Name and Description
        'has_archive' => false,
        'menu_position' => 20,
        'menu_icon' => 'dashicons-admin-post',
    );
    
    register_post_type( 'product_section', $args );
}
add_action( 'init', 'etwp_register_custom_sections' );

// Add metabox for display options
function etwp_add_meta_box() {
    add_meta_box(
        'product_section_options',
        'Product Section Options',
        'etwp_meta_box_callback',
        'product_section',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'etwp_add_meta_box' );

function etwp_meta_box_callback( $post ) {
    $selected_option = get_post_meta( $post->ID, '_etwp_selected_option', true );
    $selected_ids = get_post_meta( $post->ID, '_etwp_selected_ids', true );
    $display_position = get_post_meta( $post->ID, '_etwp_display_position', true );
    $sort_order = get_post_meta( $post->ID, '_etwp_sort_order', true );

    if ( !$selected_option ) $selected_option = '';
    if ( !$selected_ids ) $selected_ids = '';
    if ( !$display_position ) $display_position = '';
    if ( !$sort_order ) $sort_order = 10; // Default sort order

    ?>
    <label for="etwp_selected_option">Select category, tag or product:</label><br>
    <select name="etwp_selected_option" id="etwp_selected_option">
        <option value="" <?php selected( $selected_option, '' ); ?>>Show on all</option>
        <option value="category" <?php selected( $selected_option, 'category' ); ?>>Category</option>
        <option value="tag" <?php selected( $selected_option, 'tag' ); ?>>Tag</option>
        <option value="product" <?php selected( $selected_option, 'product' ); ?>>Product</option>
    </select>
    <br><br>
    <label for="etwp_selected_ids">Enter IDs (comma-separated):</label><br>
    <input type="text" name="etwp_selected_ids" id="etwp_selected_ids" value="<?php echo esc_attr( $selected_ids ); ?>" />
    <br><br>
    <label for="etwp_display_position">Display as:</label><br>
    <select name="etwp_display_position" id="etwp_display_position">
        <option value="tab" <?php selected( $display_position, 'tab' ); ?>>Tab</option>
        <option value="footer" <?php selected( $display_position, 'footer' ); ?>>Footer</option>
        <option value="under_description" <?php selected( $display_position, 'under_description' ); ?>>Under Description</option>
        <option value="in_description" <?php selected( $display_position, 'in_description' ); ?>>In Description</option>
        <option value="under_short_description" <?php selected( $display_position, 'under_short_description' ); ?>>Under Short Description</option>
        <option value="button" <?php selected( $display_position, 'button' ); ?>>Button with Popup</option>
    </select>
    <br><br>
    <label for="etwp_sort_order">Sort Order (Lower is first):</label><br>
    <input type="number" name="etwp_sort_order" id="etwp_sort_order" value="<?php echo esc_attr( $sort_order ); ?>" />
    <?php
}

// Save metabox values
function etwp_save_meta_box_data( $post_id ) {
    if ( ! isset( $_POST['etwp_selected_option'] ) || ! isset( $_POST['etwp_display_position'] ) ) {
        return;
    }

    if ( array_key_exists( 'etwp_selected_option', $_POST ) ) {
        update_post_meta(
            $post_id,
            '_etwp_selected_option',
            sanitize_text_field( $_POST['etwp_selected_option'] )
        );
    }

    if ( array_key_exists( 'etwp_selected_ids', $_POST ) ) {
        update_post_meta(
            $post_id,
            '_etwp_selected_ids',
            sanitize_text_field( $_POST['etwp_selected_ids'] )
        );
    }

    if ( array_key_exists( 'etwp_display_position', $_POST ) ) {
        update_post_meta(
            $post_id,
            '_etwp_display_position',
            sanitize_text_field( $_POST['etwp_display_position'] )
        );
    }

    if ( array_key_exists( 'etwp_sort_order', $_POST ) ) {
        update_post_meta(
            $post_id,
            '_etwp_sort_order',
            intval( $_POST['etwp_sort_order'] )
        );
    }
}
add_action( 'save_post', 'etwp_save_meta_box_data' );

// Display custom sections on WooCommerce products
function etwp_display_custom_sections() {
    global $post;

    $current_product_id = $post->ID;

    $args = array(
        'post_type' => 'product_section',
        'posts_per_page' => -1,
        'meta_key' => '_etwp_sort_order',
        'orderby' => 'meta_value_num',
        'order' => 'ASC'
    );
    
    $sections_query = new WP_Query( $args );

    if ( $sections_query->have_posts() ) {
        $tabs = []; // Array til at gemme faner

        while ( $sections_query->have_posts() ) {
            $sections_query->the_post();
            
            $section_title = get_the_title();
            // Ændret her: Brug wpautop() i stedet for wp_kses_post() for at tillade <br> tags
            $section_content = wpautop( get_the_content() );
            $selected_option = get_post_meta( get_the_ID(), '_etwp_selected_option', true );
            $selected_ids = get_post_meta( get_the_ID(), '_etwp_selected_ids', true );
            $display_position = get_post_meta( get_the_ID(), '_etwp_display_position', true );

            $show_section = false;

            // Split IDs for categories, tags or products into an array
            $selected_ids_array = array_map('trim', explode(',', $selected_ids));

            // Check if section should be displayed based on the selected option (category, tag, or product)
            if ( empty( $selected_option ) ) {
                $show_section = true; // Show on all products
            } elseif ( $selected_option == 'category' ) {
                // Check if product is in any of the specified categories
                if ( has_term( $selected_ids_array, 'product_cat', $current_product_id ) ) {
                    $show_section = true;
                }
            } elseif ( $selected_option == 'tag' ) {
                // Check if product has any of the specified tags
                if ( has_term( $selected_ids_array, 'product_tag', $current_product_id ) ) {
                    $show_section = true;
                }
            } elseif ( $selected_option == 'product' ) {
                // Check if current product matches one of the specified product IDs
                if ( in_array( $current_product_id, $selected_ids_array ) ) {
                    $show_section = true;
                }
            }

            if ( $show_section ) {
                // Håndter faner
                if ($display_position === 'tab') {
                    $tabs['custom_tab_' . get_the_ID()] = array(
                        'title'    => $section_title,
                        'priority' => 50,
                        'callback' => function() use ( $section_content ) {
                            echo wpautop( $section_content ); // Use wpautop to keep line breaks
                        }
                    );
                } else {
                    switch ($display_position) {
                        case 'footer':
                            add_action( 'woocommerce_after_single_product_summary', function() use ( $section_content ) {
                                echo '<div class="custom-product-section">' . wpautop( $section_content ) . '</div>';
                            }, 20 );
                            break;
                        case 'under_description':
                            add_action( 'woocommerce_after_single_product_summary', function() use ( $section_content ) {
                                echo '<div class="custom-product-section">' . wpautop( $section_content ) . '</div>';
                            }, 10 );
                            break;
                        case 'in_description':
                            add_filter( 'the_content', function( $content ) use ( $section_content ) {
                                return $content . '<div class="custom-product-section">' . wpautop( $section_content ) . '</div>';
                            });
                            break;
                        case 'under_short_description':
                            add_action( 'woocommerce_single_product_summary', function() use ( $section_content ) {
                                echo '<div class="custom-product-section">' . wpautop( $section_content ) . '</div>';
                            }, 20 );
                            break;
                        case 'button':
                            add_action( 'woocommerce_single_product_summary', function() use ( $section_title, $section_content ) {
                                ?>
                                <button class="custom-section-popup-button" data-popup-id="popup-<?php echo get_the_ID(); ?>"><?php echo esc_html( $section_title ); ?></button>
                                <div id="popup-<?php echo get_the_ID(); ?>" class="custom-section-popup">
                                    <div class="custom-section-popup-content">
                                        <span class="custom-section-popup-close">&times;</span>
                                        <?php echo wpautop( $section_content ); ?>
                                    </div>
                                </div>
                                <?php
                            });
                            break;
                    }
                }
            }
        }

        add_filter('woocommerce_product_tabs', function($woo_tabs) use ($tabs) {
            foreach ($tabs as $tab_key => $tab) {
                if (isset($tabs[$tab_key])) {
                    $tabs[$tab_key]['priority'] = 50; // Prioritet for at styre rækkefølgen
                }
            }
            return array_merge($woo_tabs, $tabs); // Merged tabs
        });
    }
    
    wp_reset_postdata();
}
add_action( 'woocommerce_single_product_summary', 'etwp_display_custom_sections', 10 );
